---
layout: default
title: Home
nav_order: 1
---

## Welcome to the DPEA ODrive Guide

This page is meant to be a resource to help you get your ODrive up and running as smoothly as possible.
Additionally, this is not meant to be a replacement for 
the [official ODrive documentation](https://docs.odriverobotics.com/v/latest/index.html), but rather it will 
highlight the various ways you can use Python to communicate with the existing ODrive library. 

For advanced usage of ODrive, please refer 
to the [official ODrive documentation](https://docs.odriverobotics.com/v/latest/index.html).

## Helpful Links
* [ODrive Home Page](https://odriverobotics.com/)
  * Be sure to check out the videos at the bottom of the page!
* [ODrive Docs](https://docs.odriverobotics.com/v/latest/getting-started.html)
* [ODrive Community Forum](https://discourse.odriverobotics.com/)